@@ -20,7 +20,7 @@ package Rex::Commands::Mkfs;
 use warnings;
 use strict;
 
-our $VERSION = '1.4.1'; # VERSION
+our $VERSION = '1.5.0'; # VERSION
 
 require Rex::Exporter;
 use base qw(Rex::Exporter);
@@ -28,6 +28,7 @@ use vars qw(@EXPORT);
 
 @EXPORT = qw(mkfs);
 
+use Rex::Helper::Run;
 use Rex::Commands::Run;
 use Carp;
 
@@ -47,6 +48,10 @@ Create a filesystem on device $devname.
 sub mkfs {
   my ( $devname, %option ) = @_;
 
+  if ( $devname !~ m/^\// ) {
+    $devname = "/dev/$devname";
+  }
+
   my $add_opts = "";
 
   unless ( exists $option{fstype} && defined $option{fstype} ) {
@@ -66,13 +71,13 @@ sub mkfs {
   }
 
   if ( $option{fstype} eq "swap" ) {
-    Rex::Logger::info("Creating swap space on /dev/$devname");
-    run "mkswap $add_opts -f /dev/$devname";
+    Rex::Logger::info("Creating swap space on $devname");
+    i_run "mkswap $add_opts -f $devname";
   }
   elsif ( can_run("mkfs.$option{fstype}") ) {
-    Rex::Logger::info("Creating filesystem $option{fstype} on /dev/$devname");
+    Rex::Logger::info("Creating filesystem $option{fstype} on $devname");
 
-    run "mkfs.$option{fstype} $add_opts /dev/$devname";
+    i_run "mkfs.$option{fstype} $add_opts $devname";
   }
 
   return;
