@@ -9,11 +9,7 @@ package Rex::Service::Mageia;
 use strict;
 use warnings;
 
-our $VERSION = '1.3.3'; # VERSION
-
-use Rex::Commands::Run;
-use Rex::Helper::Run;
-use Rex::Logger;
+our $VERSION = '1.5.0'; # VERSION
 
 use base qw(Rex::Service::Base);
 
